@@ -9,19 +9,20 @@ from deployer.run.standalone_shell import start as start_standalone
 from deployer.run.telnet_server import start as start_telnet_server
 
 import docopt
-import getopt
 import getpass
 import sys
 
 __doc__ = \
 """Usage:
   client.py run [-s | --single-threaded | --socket SOCKET] [--path PATH]
-                  [--non-interactive] [--log LOGFILE]
+                  [--non-interactive] [--log LOGFILE] [--scp]
                   [--] [ACTION PARAMETER...]
   client.py listen [--log LOGFILE] [--non-interactive] [--socket SOCKET]
-  client.py connect (--socket SOCKET) [--path PATH] [--] [ACTION PARAMETER...]
+  client.py connect (--socket SOCKET) [--path PATH] [--scp]
+                  [--] [ACTION PARAMETER...]
   client.py telnet-server [--port PORT] [--log LOGFILE] [--non-interactive]
   client.py list-sessions
+  client.py scp
   client.py -h | --help
   client.py --version
 
@@ -29,6 +30,7 @@ Options:
   -h, --help             : Display this help text.
   -s, --single-threaded  : Single threaded mode.
   --path PATH            : Start the shell at the node with this location.
+  --scp                  : Open a secure copy shell.
   --non-interactive      : If possible, run script with as few interactions as
                            possible.  This will always choose the default
                            options when asked for questions.
@@ -43,11 +45,18 @@ def start(root_service, name=sys.argv[0], extra_loggers=None):
     """
     a = docopt.docopt(__doc__.replace('client.py', name), version=__version__)
 
+    # "client.py scp" is a shorthand for "client.py run -s --scp"
+    if a['scp']:
+        a['run'] = True
+        a['--single-threaded'] = True
+        a['--scp'] = True
+
     interactive = not a['--non-interactive']
     action = a['ACTION']
     parameters = a['PARAMETER']
     path = a['--path'].split('.') if a['--path'] else None
     extra_loggers = extra_loggers or []
+    scp = a['--scp']
 
     # Socket name variable
     # In case of integers, they map to /tmp/deployer.sock.username.X
@@ -75,13 +84,14 @@ def start(root_service, name=sys.argv[0], extra_loggers=None):
 
     # Connect to socket
     elif a['connect']:
-        start_client(socket_name, path, action_name=action, parameters=parameters)
+        start_client(socket_name, path, action_name=action, parameters=parameters,
+                open_scp_shell=scp)
 
     # Single threaded client
     elif a['run'] and a['--single-threaded']:
         start_standalone(root_service, interactive=interactive, cd_path=path,
                 action_name=action, parameters=parameters, logfile=a['--log'],
-                extra_loggers=extra_loggers)
+                extra_loggers=extra_loggers, open_scp_shell=scp)
 
     # Multithreaded
     elif a['run']:
@@ -92,7 +102,8 @@ def start(root_service, name=sys.argv[0], extra_loggers=None):
                     shutdown_on_last_disconnect=True, interactive=interactive,
                     logfile=a['--log'], extra_loggers=extra_loggers)
 
-        start_client(socket_name, path, action_name=action, parameters=parameters)
+        start_client(socket_name, path, action_name=action, parameters=parameters,
+                open_scp_shell=scp)
 
 
 if __name__ == '__main__':
