@@ -94,6 +94,11 @@ class HostContext(object):
     def env(self, variable, value, escape=True):
         """
         Set this environment variable
+
+        ::
+
+            with host.cd('VAR', 'my-value'):
+                host.run('echo $VAR')
         """
         if value is None:
             value = ''
@@ -150,6 +155,11 @@ class Host(object):
     """
     Definiton of a remote host. An instance will open an SSH connection
     according to the settings defined in the class definition.
+
+    :param pty: The pseudo terminal wrapper which handles the stdin/stdout.
+    :type pty: :class:`deployer.pseudo_terminal.Pty`
+    :param logger: The logger interface.
+    :type logger: LoggerInterface
     """
     #class __metaclass__(type):
     #    @property
@@ -308,8 +318,6 @@ class Host(object):
         """
         Execute this shell command on the host.
 
-        :param pty: The pseudo terminal wrapper which handles the stdin/stdout.
-        :type pty: :class:`deployer.pseudo_terminal.Pty`
         :param command: The shell command.
         :type command: basestring
         :param use_sudo: Run as superuser.
@@ -319,8 +327,6 @@ class Host(object):
         :param interactive: Start an interactive event loop which allows
                             interaction with the remote command. Otherwise, just return the output.
         :type interactive: bool
-        :param logger: The logger interface.
-        :type logger: LoggerInterface
         :param initial_input: When ``interactive``, send this input first to the host.
         """
         assert isinstance(command, basestring)
@@ -480,11 +486,6 @@ class Host(object):
         result = []
         password_sent = False
 
-        # Make stdin non-blocking. (The select call will already
-        # block for us, we want sys.stdin.read() to read as many
-        # bytes as possible without blocking.)
-        fdesc.setNonBlocking(self.pty.stdin)
-
         # Set terminal in raw mode
         if raw:
             context = raw_mode(self.pty.stdin)
@@ -510,6 +511,11 @@ class Host(object):
                     if chan.status_event.isSet():
                         break;
 
+                    # Make stdin non-blocking. (The select call will already
+                    # block for us, we want sys.stdin.read() to read as many
+                    # bytes as possible without blocking.)
+                    fdesc.setNonBlocking(self.pty.stdin)
+
                     if reading_from_stdin:
                         r, w, e = select([self.pty.stdin, chan], [], [])
                     else:
@@ -520,6 +526,13 @@ class Host(object):
                         try:
                             x = chan.recv(1024)
 
+                            # Set stdin blocking again
+                            # (Writing works better in blocking mode.
+                            # Especially OS X seems to be very sensitive if we
+                            # write lange amounts [>1000 bytes] nonblocking to
+                            # stdout. That causes a lot of IOErrors.)
+                            fdesc.setBlocking(self.pty.stdin)
+
                             # Received length 0 -> end of stream
                             if len(x) == 0:
                                 break
@@ -532,7 +545,7 @@ class Host(object):
                                 try:
                                     self.pty.stdout.write(x)
                                     break
-                                except IOError, e:
+                                except IOError as e:
                                     # Sometimes, when we have a lot of output, we get here:
                                     # IOError: [Errno 11] Resource temporarily unavailable
                                     # Just waiting a little, and retrying seems to work.
@@ -566,7 +579,7 @@ class Host(object):
                             # difference became clear is in redis-cli, which
                             # only accepts \r as confirmation.)
                             x = x.replace('\n', '\r')
-                        except IOError, e:
+                        except IOError as e:
                             # What to do with IOError exceptions?
                             # (we see what happens in the next select-call.)
                             continue
